import argparse


def add_archive_parser(top_level_parsers: argparse._SubParsersAction):
    parser: argparse.ArgumentParser = top_level_parsers.add_parser("archive")
    subsub = parser.add_subparsers(dest='archive',
                                   required=True)

    add = subsub.add_parser("add")
    add.add_argument("files",
                     help="files to add to archive",
                     default=[],
                     nargs="+")
    add.add_argument("-a", "--archive",
                     help="path to archive",
                     dest="archive_path",
                     nargs=1,
                     required=True)

    add.add_argument("-p", "--path",
                     help="path inside archive where files will be placed",
                     dest="basepath",
                     default="")
    add.set_defaults(func=run_archive_add)

    create = subsub.add_parser("create")
    create.add_argument("-a", "--archive",
                        help="path to archive",
                        dest="archive_path",
                        nargs=1,
                        required=True)
    create.set_defaults(func=run_archive_create)


def run_archive_add(args):
    from pictures.add import add
    add(archive_path=args.archive_path[0],
        files_to_add=args.files,
        basepath=args.basepath)


def run_archive_create(args):
    from pictures.create import create
    create(args.archive_path[0])
