# Util functions for picture archive

from zipfile import ZipFile, is_zipfile, ZIP_LZMA
from os.path import isfile, basename, splitext


ARCHIVE_MARKER_FILE = "PICARCHIVE"


def check_valid_archive(path: str) -> bool:
    if not isfile(path):
        return False
    if not is_zipfile(path):
        return False
    try:
        with ZipFile(path, 'r') as zip:
            if ARCHIVE_MARKER_FILE not in zip.namelist():
                return False
    except Exception:
        return False

    return True


def create_new_archive(path: str):
    if check_valid_archive(path):
        raise FileExistsError("Archive already exists")
    if isfile(path):
        raise FileExistsError("A file with that name already exists")

    with ZipFile(path, 'x',
                 compression=ZIP_LZMA,
                 allowZip64=True) as zip:
        with zip.open(ARCHIVE_MARKER_FILE, 'w') as f:
            f.write("horses".encode())


def get_already_existing_files(path: str, files: [str]) -> [str]:
    if not check_valid_archive(path):
        raise ValueError("Archive is not valid")

    with ZipFile(path, 'r') as zip:
        existing_files_set = {basename(p) for p in zip.namelist()}

    arg_files_set = {basename(p) for p in files}
    return list(existing_files_set & arg_files_set)


def check_ext(path: str, valid: [str]) -> bool:
    return splitext(path)[1].upper() in [x.upper() for x in valid]


def check_jpg(path: str) -> bool:
    return check_ext(path, [".JPG", ".JPEG"])
